



if not exist "%LIBRARY_LIB%\\pdfium.dll.lib" exit 1
IF %ERRORLEVEL% NEQ 0 exit /B 1
if not exist "%LIBRARY_BIN%\\pdfium.dll" exit 1
IF %ERRORLEVEL% NEQ 0 exit /B 1
if not exist "%LIBRARY_LIB%\\..\\include\\fpdf_annot.h" exit 1
IF %ERRORLEVEL% NEQ 0 exit /B 1
if not exist "%LIBRARY_LIB%\\..\\include\\fpdf_attachment.h" exit 1
IF %ERRORLEVEL% NEQ 0 exit /B 1
if not exist "%LIBRARY_LIB%\\..\\include\\fpdf_catalog.h" exit 1
IF %ERRORLEVEL% NEQ 0 exit /B 1
if not exist "%LIBRARY_LIB%\\..\\include\\fpdf_dataavail.h" exit 1
IF %ERRORLEVEL% NEQ 0 exit /B 1
if not exist "%LIBRARY_LIB%\\..\\include\\fpdf_doc.h" exit 1
IF %ERRORLEVEL% NEQ 0 exit /B 1
if not exist "%LIBRARY_LIB%\\..\\include\\fpdf_edit.h" exit 1
IF %ERRORLEVEL% NEQ 0 exit /B 1
if not exist "%LIBRARY_LIB%\\..\\include\\fpdf_ext.h" exit 1
IF %ERRORLEVEL% NEQ 0 exit /B 1
if not exist "%LIBRARY_LIB%\\..\\include\\fpdf_flatten.h" exit 1
IF %ERRORLEVEL% NEQ 0 exit /B 1
if not exist "%LIBRARY_LIB%\\..\\include\\fpdf_formfill.h" exit 1
IF %ERRORLEVEL% NEQ 0 exit /B 1
if not exist "%LIBRARY_LIB%\\..\\include\\fpdf_fwlevent.h" exit 1
IF %ERRORLEVEL% NEQ 0 exit /B 1
if not exist "%LIBRARY_LIB%\\..\\include\\fpdf_javascript.h" exit 1
IF %ERRORLEVEL% NEQ 0 exit /B 1
if not exist "%LIBRARY_LIB%\\..\\include\\fpdf_ppo.h" exit 1
IF %ERRORLEVEL% NEQ 0 exit /B 1
if not exist "%LIBRARY_LIB%\\..\\include\\fpdf_progressive.h" exit 1
IF %ERRORLEVEL% NEQ 0 exit /B 1
if not exist "%LIBRARY_LIB%\\..\\include\\fpdf_save.h" exit 1
IF %ERRORLEVEL% NEQ 0 exit /B 1
if not exist "%LIBRARY_LIB%\\..\\include\\fpdf_searchex.h" exit 1
IF %ERRORLEVEL% NEQ 0 exit /B 1
if not exist "%LIBRARY_LIB%\\..\\include\\fpdf_signature.h" exit 1
IF %ERRORLEVEL% NEQ 0 exit /B 1
if not exist "%LIBRARY_LIB%\\..\\include\\fpdf_structtree.h" exit 1
IF %ERRORLEVEL% NEQ 0 exit /B 1
if not exist "%LIBRARY_LIB%\\..\\include\\fpdf_sysfontinfo.h" exit 1
IF %ERRORLEVEL% NEQ 0 exit /B 1
if not exist "%LIBRARY_LIB%\\..\\include\\fpdf_text.h" exit 1
IF %ERRORLEVEL% NEQ 0 exit /B 1
if not exist "%LIBRARY_LIB%\\..\\include\\fpdf_thumbnail.h" exit 1
IF %ERRORLEVEL% NEQ 0 exit /B 1
if not exist "%LIBRARY_LIB%\\..\\include\\fpdf_transformpage.h" exit 1
IF %ERRORLEVEL% NEQ 0 exit /B 1
if not exist "%LIBRARY_LIB%\\..\\include\\fpdfview.h" exit 1
IF %ERRORLEVEL% NEQ 0 exit /B 1
exit /B 0
